import { ContentConfig, CustomPrintConfig, PageConfig, PrintConfig } from '@sinoform/types';
import { StateWithHistory } from 'redux-undo';
import { BorderType } from '../constants';
export declare enum ActionType {
    /**
     * 合并和拆分单元格
     */
    MERGE_CELLS = "MERGE_CELLS",
    /**
     * 拖动行高
     */
    CHANGE_ROW_HEIGHT = "CHANGE_ROW_HEIGHT",
    /**
     * 拖动列宽
     */
    CHANGE_COL_WIDTH = "CHANGE_COL_WIDTH",
    /**
     * 编辑单元格内容
     * 1. 手动编辑单元格内容
     * 2. 拖拽表单项到单元格
     */
    EDIT_CELL_VALUE = "EDIT_CELL_VALUE",
    /**
     * 设置单元格文本样式
     */
    SET_CELLS_TEXT_STYLE = "SET_CELLS_TEXT_STYLE",
    /**
     * 设置单元格样式
     */
    SET_CELLS_STYLE = "SET_CELLS_STYLE",
    /**
     * 设置边框样式
     */
    SET_CELLS_BORDER_STYLE = "SET_CELLS_BORDER_STYLE",
    /**
     * 单元格复制
     */
    COPY_CELL = "COPY_CELL",
    /**
     * 单元格剪切
     */
    CUT_CELL = "CUT_CELL",
    /**
     * 插入行
     */
    INSERT_ROW = "INSERT_ROW",
    /**
     * 插入列
     */
    INSERT_COL = "INSERT_COL",
    /**
     * 删除行
     */
    DELETE_ROW = "DELETE_ROW",
    /**
     * 删除列
     */
    DELETE_COL = "DELETE_COL",
    /**
     * 页面设置
     */
    SET_PRINT_CONFIG = "SET_PRINT_CONFIG",
    /**
     * 切换编辑状态的单元格
     */
    SET_EDITING_CELL = "SET_EDITING_CELL",
    REPLACE_CONFIG = "REPLACE_CONFIG"
}
/**
 * 单元格位置：分别对应起始位置和结束位置
 */
export declare type CellPos = [number, number];
/**
 * 单元格区域：分别对应起始位置和结束位置
 */
export declare type CellRange = [CellPos, CellPos];
/**
 * 在指定位置新增行的动作
 */
export interface InsertRowAction {
    type: ActionType.INSERT_ROW;
    payload: number;
}
/**
 * 删除指定行的动作
 */
export interface DeleteRowAction {
    type: ActionType.DELETE_ROW;
    payload: {
        from: number;
        len: number;
    };
}
export declare type MergeCellAction = {
    type: ActionType.MERGE_CELLS;
    payload: {
        fromCell: CellPos;
        toCell: CellPos;
    };
};
export declare type ChangeRowHeightAction = {
    type: ActionType.CHANGE_ROW_HEIGHT;
    payload: {
        rowIdx: number;
        height: number;
    };
};
export declare type ChangeColWidthAction = {
    type: ActionType.CHANGE_COL_WIDTH;
    payload: {
        colIdx: number;
        width: number;
    };
};
/**
 * 在指定位置新增列的动作
 */
export interface InsertColAction {
    type: ActionType.INSERT_COL;
    payload: number;
}
/**
 * 删除指定列的动作
 */
export interface DeleteColAction {
    type: ActionType.DELETE_COL;
    payload: {
        startCol: number;
        endCol: number;
    };
}
/**
 * 单元格复制
 */
export interface CopyCellAction {
    type: ActionType.COPY_CELL;
    payload: {
        source: CellRange;
        target: CellPos;
    };
}
/**
 * 单元格剪切
 */
export interface CutCellAction {
    type: ActionType.CUT_CELL;
    payload: {
        source: CellRange;
        target: CellPos;
    };
}
/**
 * 编辑单元格内容的动作
 */
export interface EditCellValueAction {
    type: ActionType.EDIT_CELL_VALUE;
    payload: {
        cellPos: CellPos;
        value: any;
    };
}
/**
 * 设置单元格样式，边框样式
 */
export interface SetCellsBorderAction {
    type: ActionType.SET_CELLS_BORDER_STYLE;
    payload: {
        range: CellRange;
        type: BorderType;
        style?: any;
    };
}
/**
 * 设置单元格样式的动作，水平、垂直位置
 */
export interface SetCellsStyleAction {
    type: ActionType.SET_CELLS_STYLE;
    payload: {
        cells: CellPos[];
        style: {
            [x: string]: string;
        };
    };
}
/**
 * 设置单元格文本样式的动作
 */
export interface SetCellsTextStyleAction {
    type: ActionType.SET_CELLS_TEXT_STYLE;
    payload: {
        cells: CellPos[];
        items: any[];
    };
}
export interface SetPageConfigAction {
    type: ActionType.SET_PRINT_CONFIG;
    payload: PrintConfig;
}
/**
 * 设置处在编辑状态的单元格位置
 */
export interface SetEditingCellAction {
    type: ActionType.SET_EDITING_CELL;
    payload: CellPos;
}
export interface ReplaceConfigAction {
    type: ActionType.REPLACE_CONFIG;
    payload: State;
}
export interface ReduxPrintConfig {
    pageConfig: PageConfig;
    contentConfig: ContentConfig;
}
export interface State extends CustomPrintConfig {
    config: ReduxPrintConfig;
    editingCell?: CellPos;
}
export declare type Action = InsertRowAction | DeleteRowAction | InsertColAction | DeleteColAction | ChangeColWidthAction | ChangeRowHeightAction | MergeCellAction | CopyCellAction | CutCellAction | EditCellValueAction | SetCellsStyleAction | SetCellsTextStyleAction | SetPageConfigAction | SetCellsBorderAction | SetEditingCellAction | ReplaceConfigAction;
export declare type UndoState = StateWithHistory<State>;
